summaryrefslogtreecommitdiffstats
path: root/src/bin/dhcp6/tests/dhcp6_test_utils.cc
diff options
context:
space:
mode:
authorFrancis Dupont <fdupont@isc.org>2017-05-11 14:12:07 +0200
committerFrancis Dupont <fdupont@isc.org>2017-05-11 14:12:07 +0200
commit95ef2e1ec60bfa9f191ef29e843554b641ed4beb (patch)
tree6f60e4982026846c17e5b82172efc536728f05fe /src/bin/dhcp6/tests/dhcp6_test_utils.cc
parent[trac3389a] regen flex/bison (diff)
downloadkea-95ef2e1ec60bfa9f191ef29e843554b641ed4beb.tar.xz
kea-95ef2e1ec60bfa9f191ef29e843554b641ed4beb.zip
[3389a] Renamed patchIfacesReDetect into disableIfacesReDetect
Diffstat (limited to 'src/bin/dhcp6/tests/dhcp6_test_utils.cc')
-rw-r--r--src/bin/dhcp6/tests/dhcp6_test_utils.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/bin/dhcp6/tests/dhcp6_test_utils.cc b/src/bin/dhcp6/tests/dhcp6_test_utils.cc
index 70b64d4189..b836b8fbc9 100644
--- a/src/bin/dhcp6/tests/dhcp6_test_utils.cc
+++ b/src/bin/dhcp6/tests/dhcp6_test_utils.cc
@@ -702,8 +702,8 @@ Dhcpv6SrvTest::configure(const std::string& config, NakedDhcpv6Srv& srv) {
ASSERT_NO_THROW(json = parseJSON(config));
ConstElementPtr status;
- // Patch the re-detect flag
- patchIfacesReDetect(json);
+ // Disable the re-detect flag
+ disableIfacesReDetect(json);
// Configure the server and make sure the config is accepted
EXPECT_NO_THROW(status = configureDhcp6Server(srv, json));